package org.gcube.portlets.user.geoportaldataentry.client.events;

import org.gcube.application.geoportalcommon.shared.SearchingFilter;

import com.google.gwt.event.shared.GwtEvent;

/**
 * The Class CreateNewProjectEvent.
 *
 * @author Francesco Mangiacrapa at ISTI-CNR (francesco.mangiacrapa@isti.cnr.it)
 * 
 *         Oct 13, 2020
 */
public class GetListOfRecordsEvent extends GwtEvent<GetListOfRecordsEventHandler> {

	/** The type. */
	public static Type<GetListOfRecordsEventHandler> TYPE = new Type<GetListOfRecordsEventHandler>();
	private SearchingFilter sortFilter;
	private String profileID;
	private String projectName;
	private Boolean reloadFilteringParameters = false;

	/**
	 * Instantiates a new cancel upload event.
	 *
	 * @param projectName the project name
	 * @param profileID the profile ID
	 * @param sortFilter     the sort filter
	 * @param reloadFilteringParameters the reload filtering parameters
	 */
	public GetListOfRecordsEvent(String projectName, String profileID, SearchingFilter sortFilter,
			Boolean reloadFilteringParameters) {
		this.sortFilter = sortFilter;
		this.profileID = profileID;
		this.projectName = projectName;
		this.reloadFilteringParameters = reloadFilteringParameters;
	}

	/**
	 * Gets the associated type.
	 *
	 * @return the associated type
	 */
	/*
	 * (non-Javadoc)
	 * 
	 * @see com.google.gwt.event.shared.GwtEvent#getAssociatedType()
	 */
	@Override
	public Type<GetListOfRecordsEventHandler> getAssociatedType() {
		return TYPE;
	}

	/**
	 * Dispatch.
	 *
	 * @param handler the handler
	 */
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.google.gwt.event.shared.GwtEvent#dispatch(com.google.gwt.event.shared.
	 * EventHandler)
	 */
	@Override
	protected void dispatch(GetListOfRecordsEventHandler handler) {
		handler.onGetList(this);
	}

	/**
	 * Gets the sort filter.
	 *
	 * @return the sort filter
	 */
	public SearchingFilter getSortFilter() {
		return sortFilter;
	}

	/**
	 * Gets the profile ID.
	 *
	 * @return the profile ID
	 */
	public String getProfileID() {
		return profileID;
	}

	/**
	 * Gets the project name.
	 *
	 * @return the project name
	 */
	public String getProjectName() {
		return projectName;
	}

	/**
	 * Gets the reload filtering parameters.
	 *
	 * @return the reload filtering parameters
	 */
	public boolean isReloadFilteringParameters() {
		return reloadFilteringParameters;
	}

}
